# Copyright 2018 Canonical Ltd.
#
# This file is part of the Cassandra cqlsh Charm for Juju.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from charmhelpers.core import (
    hookenv,
    host,
)
from charms import reactive
from charms.reactive import (
    hook,
    when,
    when_not,
)
from charms.reactive.flags import register_trigger


register_trigger(when='endpoint.database.changed', clear_flag='cqlsh.configured')


@when('endpoint.database.available')
@when_not('cqlsh.configured')
def configure():
    ep = reactive.endpoint_from_flag('endpoint.database.available')
    ep.write_cqlshrc('root')
    ep.write_cqlshrc('ubuntu')
    reactive.set_flag('cqlsh.configured')
    hookenv.status_set('active', 'Available')


@when_not('endpoint.database.joined')
def blocked():
    hookenv.status_set('blocked', 'Requires relation to Cassandra')


@when('endpoint.database.joined')
@when_not('endpoint.database.available')
def waiting():
    hookenv.status_set('waiting', 'Waiting for Cassandra')


@hook('upgrade-charm')
def upgrade_charm():
    reactive.clear_flag('cqlsh.installed')


@when_not('cqlsh.installed')
def install():
    host.service_pause('cassandra')
    reactive.set_flag('cqlsh.installed')
